from django import forms
from django.db.models import Q
from releases.models import Distro
from system_configs.models import SystemConfig, SystemUnit

MIN_STARS = (
    (1, '1 star or more'),
    (2, '2 stars or more'),
    (3, '3 stars or more'),
    (4, '4 stars or more'),
    (5, '5 stars'),
)

POPULARITY = (
    ('any', 'Any system'),
    ('popular', 'Popular systems'),
)


def as_dl(self):
    return self._html_output(u'<dt id=\'dt_%(label)s\'>%(label)s</dt><dd>%(field)s</dd>',
        u'%s', '</p>', u' %s', True)


class SearchFiltersForm(forms.Form):
    desktops = forms.BooleanField(required=False, initial=True)
    laptops = forms.BooleanField(required=False, initial=True)
    stars = forms.ChoiceField(choices=MIN_STARS, initial=3)
    release = forms.ModelChoiceField(
        queryset=Distro.objects.all().order_by('-i_version'), empty_label=None)
    popularity = forms.ChoiceField(choices=POPULARITY)

    as_dl = as_dl

    def search(self, term=None):
        if not self.is_valid():
            return SystemConfig.objects.none()

        data = self.cleaned_data

        if data['popularity'] == 'popular':
            qs = SystemConfig.objects.filter(
                pk__in=[c.id for c in SystemConfig.objects\
                    .filter(release=data['release'])\
                    .order_by('-num_ratings', '-overall_rating')[:50]])
        else:
            qs = SystemConfig.objects.all()

        qs = qs.filter(overall_rating__gte=data['stars'],
                                         release=data['release'])


        if data['desktops'] or data['laptops']:
            form_factor_q = Q()
            if data['desktops']:
                form_factor_q = form_factor_q | Q(form_factor='desktop')
            if data['laptops']:
                form_factor_q = form_factor_q | Q(form_factor='laptop')
            qs = qs.filter(form_factor_q)

        if term is not None:
            q = Q()
            terms = term.split(' ')
            for t in terms:
                this_term = Q(make__istartswith=t) | Q(model__icontains=t)
                q = q & this_term
            qs = qs.filter(q)
            if term.startswith('testruns/'):
                qs = SystemConfig.objects.filter(pk__in=[s.config.id for s in 
                    SystemUnit.objects.filter(
                        test_run_source__iendswith=term)])

        return qs
