from django.http import HttpResponseRedirect
from django.conf import settings
from django.shortcuts import redirect
from re import compile

class LoginRequiredMiddleware:
    """
    Middleware that requires a user to be authenticated to view the admin and util views.

    Requires authentication middleware and template context processors to be
    loaded. You'll get an error if they aren't.
    """
    def process_request(self, request):
        assert hasattr(request, 'user'), "The Login Required middleware\
                requires authentication middleware to be installed. Edit your\
                MIDDLEWARE_CLASSES setting to insert\
                'django.contrib.auth.middlware.AuthenticationMiddleware'. If that doesn't\
                work, ensure your TEMPLATE_CONTEXT_PROCESSORS setting includes\
                'django.core.context_processors.auth'."
        if not request.user.is_authenticated():
            path = request.path_info.lstrip('/')
            if path.startswith('admin') or path.startswith('util'):
                return HttpResponseRedirect(settings.LOGIN_URL)
        return None
