from django.test import TestCase
from system_configs.models import SystemConfig
from releases.models import Distro
from browse.forms import SearchFiltersForm

class SearchFilterFormTest(TestCase):
    def setUp(self):
        self.tenfour = Distro.objects.get_or_create(release='10.04')[0]
        self.tenten = Distro.objects.get_or_create(release='10.10')[0]
        self.elevenfour = Distro.objects.get_or_create(release='11.04')[0]

        sc = SystemConfig(make ='Dell',
                          model = 'Vostro 3300',
                          form_factor = 'desktop',
                          release = self.tenfour,
                          overall_rating = '3.7',
                          num_ratings = 121)
        sc.save()
        self.vostro_tenfour = sc
        
        sc = SystemConfig(make ='Dell',
                          model = 'Vostro 3300',
                          form_factor = 'desktop',
                          release = self.tenten,
                          overall_rating = '4.3',
                          num_ratings = 195)
        sc.save()
        self.vostro_tenten = sc

        sc = SystemConfig(make ='Dell',
                          model = 'Inspiron 1234',
                          form_factor = 'laptop',
                          release = self.tenten,
                          overall_rating = '4.9',
                          num_ratings = 56)
        sc.save()
        self.inspiron_tenten = sc

    def test_simple_search_filter(self):
        expected = self.vostro_tenfour
        f = SearchFiltersForm({'desktops': '1', 
                               'release': self.tenfour.id, 
                               'popularity': 'any', 
                               'stars': '3'})
        results = f.search()
        self.assertEqual(results.count(), 1)
        self.assertEqual(results[0], expected)
    
        f = SearchFiltersForm({'laptops': '1', 
                               'release': self.tenfour.id, 
                               'popularity': 'any', 
                               'stars': '3'})
        results = f.search()
        self.assertEqual(results.count(), 0)

        expected = self.vostro_tenfour
        f = SearchFiltersForm({'desktops': '1', 
                               'laptops': '1',
                               'release': self.tenfour.id, 
                               'popularity': 'any', 
                               'stars': '3'})
        results = f.search()
        self.assertEqual(results.count(), 1)
        self.assertEqual(results[0], expected)

        f = SearchFiltersForm({'desktops': '1', 
                               'laptops': '1',
                               'release': self.tenfour.id, 
                               'popularity': 'any', 
                               'stars': '5'})
        results = f.search()
        self.assertEqual(results.count(), 0)

    def test_filter_with_term(self):
        f = SearchFiltersForm({'desktops': '1', 
                              'release': self.tenfour.id, 
                              'popularity': 'any', 
                              'stars': '3'})
        results = f.search(term='blahblah')
        self.assertEqual(results.count(), 0)

        expected = self.vostro_tenfour
        f = SearchFiltersForm({'desktops': '1', 
                              'release': self.tenfour.id, 
                              'popularity': 'any', 
                              'stars': '3'})
        results = f.search(term='dell 3300')
        self.assertEqual(results.count(), 1)
        self.assertEqual(results[0], expected)

