from django.db import models

import datetime


class DistroManager(models.Manager):
    def get_distro(self, release, codename=''):
        try:
            distro = self.get(release__startswith=release)
        except self.model.DoesNotExist:
            distro = self.create(release=release, codename=codename)
        return distro
    
    def get_latest_distro(self):
        return self.all().order_by('-i_release')[0]

class SupportedDistroManager(models.Manager):
    def get_query_set(self):
        return super(SupportedDistroManager, self).get_query_set() \
                        .filter( models.Q(supported_until__gte = datetime.date.today())
                               | models.Q(supported_until__isnull=True))

class Distro(models.Model):
    codename = models.CharField(max_length=24)
    release = models.CharField(max_length=10)
    supported_until = models.DateField(blank=True, null=True)
    i_version = models.IntegerField(blank=True, null=True)
    is_latest = models.BooleanField(default=False)
    is_lts = models.BooleanField(default=False)
    
    supported = SupportedDistroManager()
    objects = DistroManager()

    class Meta:
        ordering = ('i_version','release')

    def __unicode__(self):
        if self.is_latest:
            return u'%s (latest release)' % self.release
        return self.release

    def save(self, *args, **kwargs):
        import re
        num = re.compile('[^0-9\.]')
        try:
            version = map(int, num.sub('', self.release).split('.'))
            self.i_version = int(version[0])*100 + int(version[1])
        except:
            pass
        super(Distro, self).save(*args, **kwargs)
        if self.is_latest:
            Distro.objects.all().exclude(id=self.id).update(is_latest=False)
