from django.test import TestCase

from releases.models import Distro

from datetime import date, timedelta


class ReleasesModelsTest(TestCase):
    """
    Tests for the releases app models.
    """

    def test_get_distro(self):
        Distro.objects.create(
                codename='lucid',
                release='10.04 LTS')

        distro = Distro.objects.get_distro('10.04', 'lucid')
        self.failUnless(distro)
        self.assertEquals(str(distro), '10.04 LTS')

        distro = Distro.objects.get_distro('11.04', 'natty')
        self.failUnless(distro)
        self.assertEquals(str(distro), '11.04')

    def test_supported(self):
        _today = date.today()
        _yesterday = _today - timedelta(1)
        _tomorrow = _today + timedelta(1)

        yesterday = Distro.objects.create(
                codename='yesterday',
                release='yesterday',
                supported_until=_yesterday)

        today = Distro.objects.create(
                codename='today',
                release='today',
                supported_until=_today)

        tomorrow = Distro.objects.create(
                codename='tomorrow',
                release='tomorrow',
                supported_until=_tomorrow)

        never = Distro.objects.create(
                codename='never',
                release='never')

        supported = Distro.supported.all()
        self.failUnless(supported)
        self.assertFalse(yesterday in supported)
        self.assertTrue(today in supported)
        self.assertTrue(tomorrow in supported)
        self.assertTrue(never in supported)

    def test_release_unicode(self):
        d = Distro(
                codename='lucid',
                release='10.04 LTS')
        d.save()

        self.failUnless(d)
        self.assertEquals(d.__unicode__(), '10.04 LTS')
    
    def test_release_minor_major(self):
        distro = Distro.objects.get_distro('10.04', 'lucid')
        self.assertEqual(distro.i_version, 1004)

