from django.core.management.base import NoArgsCommand
from optparse import make_option
from releases.models import Distro
from results.api import ResultsImporter
from results.models import ImportSchedule
import datetime


UF_EPOCH = datetime.datetime(2011, 9, 1)


class Command(NoArgsCommand):
    help = 'Imports results for a certain release from the Results Tracker'

    option_list = NoArgsCommand.option_list + (
        make_option('--release',
            dest='release',
            help='Ubuntu release, e.g. 10.10'),
        make_option('--age',
            dest='age',
            help='Maximum age of results to import in hours (default 2)'),
        make_option('--sequence',
            dest='test_run_sequence',
            help='Sequence of test run to import'),
        )

    def handle_noargs(self, **options):
        releases = Distro.objects.all()
        now = datetime.datetime.now()
        for release in releases:
            schedule, created = ImportSchedule.objects.get_or_create(
                release=release)
            print schedule
            if created:
                complete_refresh = True
            else:
                complete_refresh = False
                delta = now - schedule.import_since
                schedule.import_since = now
                if schedule.full_refresh:
                    complete_refresh = True
                    schedule.full_refresh = False

            if complete_refresh:
                # since the beginning of UF
                delta = now - UF_EPOCH

            age = int(delta.days * 24 + delta.seconds / 60.0 / 60.0 + 1)

            i = ResultsImporter(release, age)
            i.import_results(
                schedule,
                complete_refresh=complete_refresh,
                test_run_sequence=options.get('test_run_sequence'))
