# encoding: utf-8
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models

class Migration(SchemaMigration):

    depends_on = (
        ('releases', '0002_auto__add_field_distro_is_latest__add_field_distro_is_lts'),
    )

    def forwards(self, orm):
        
        # Deleting model 'ImportRun'
        db.delete_table('results_importrun')

        # Adding model 'SkippableTest'
        db.create_table('results_skippabletest', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('release', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['releases.Distro'])),
            ('uf_category', self.gf('django.db.models.fields.CharField')(max_length=64)),
            ('test', self.gf('django.db.models.fields.CharField')(max_length=64)),
        ))
        db.send_create_signal('results', ['SkippableTest'])

        # Adding unique constraint on 'SkippableTest', fields ['release', 'uf_category', 'test']
        db.create_unique('results_skippabletest', ['release_id', 'uf_category', 'test'])

        # Adding model 'ImportLock'
        db.create_table('results_importlock', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('locked_by', self.gf('django.db.models.fields.CharField')(max_length=64)),
        ))
        db.send_create_signal('results', ['ImportLock'])

        # Adding model 'TestMapping'
        db.create_table('results_testmapping', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('release', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['releases.Distro'])),
            ('incoming_test', self.gf('django.db.models.fields.CharField')(max_length=128)),
            ('mapped_test', self.gf('django.db.models.fields.CharField')(max_length=128)),
        ))
        db.send_create_signal('results', ['TestMapping'])

        # Adding unique constraint on 'TestMapping', fields ['release', 'incoming_test', 'mapped_test']
        db.create_unique('results_testmapping', ['release_id', 'incoming_test', 'mapped_test'])

        # Adding model 'CategoryMapping'
        db.create_table('results_categorymapping', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('release', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['releases.Distro'])),
            ('incoming_category', self.gf('django.db.models.fields.CharField')(max_length=64)),
            ('uf_category', self.gf('django.db.models.fields.CharField')(max_length=64)),
        ))
        db.send_create_signal('results', ['CategoryMapping'])

        # Adding unique constraint on 'CategoryMapping', fields ['release', 'incoming_category', 'uf_category']
        db.create_unique('results_categorymapping', ['release_id', 'incoming_category', 'uf_category'])


    def backwards(self, orm):
        
        # Removing unique constraint on 'CategoryMapping', fields ['release', 'incoming_category', 'uf_category']
        db.delete_unique('results_categorymapping', ['release_id', 'incoming_category', 'uf_category'])

        # Removing unique constraint on 'TestMapping', fields ['release', 'incoming_test', 'mapped_test']
        db.delete_unique('results_testmapping', ['release_id', 'incoming_test', 'mapped_test'])

        # Removing unique constraint on 'SkippableTest', fields ['release', 'uf_category', 'test']
        db.delete_unique('results_skippabletest', ['release_id', 'uf_category', 'test'])

        # Adding model 'ImportRun'
        db.create_table('results_importrun', (
            ('triggered_by', self.gf('django.db.models.fields.CharField')(max_length=24)),
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('last_run', self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, blank=True)),
        ))
        db.send_create_signal('results', ['ImportRun'])

        # Deleting model 'SkippableTest'
        db.delete_table('results_skippabletest')

        # Deleting model 'ImportLock'
        db.delete_table('results_importlock')

        # Deleting model 'TestMapping'
        db.delete_table('results_testmapping')

        # Deleting model 'CategoryMapping'
        db.delete_table('results_categorymapping')


    models = {
        'releases.distro': {
            'Meta': {'ordering': "('i_version', 'release')", 'object_name': 'Distro'},
            'codename': ('django.db.models.fields.CharField', [], {'max_length': '24'}),
            'i_version': ('django.db.models.fields.IntegerField', [], {'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'is_latest': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'is_lts': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'release': ('django.db.models.fields.CharField', [], {'max_length': '10'}),
            'supported_until': ('django.db.models.fields.DateField', [], {'null': 'True', 'blank': 'True'})
        },
        'results.categorymapping': {
            'Meta': {'unique_together': "[('release', 'incoming_category', 'uf_category')]", 'object_name': 'CategoryMapping'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'incoming_category': ('django.db.models.fields.CharField', [], {'max_length': '64'}),
            'release': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['releases.Distro']"}),
            'uf_category': ('django.db.models.fields.CharField', [], {'max_length': '64'})
        },
        'results.importlock': {
            'Meta': {'object_name': 'ImportLock'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'locked_by': ('django.db.models.fields.CharField', [], {'max_length': '64'})
        },
        'results.skippabletest': {
            'Meta': {'unique_together': "[('release', 'uf_category', 'test')]", 'object_name': 'SkippableTest'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'release': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['releases.Distro']"}),
            'test': ('django.db.models.fields.CharField', [], {'max_length': '64'}),
            'uf_category': ('django.db.models.fields.CharField', [], {'max_length': '64'})
        },
        'results.testmapping': {
            'Meta': {'unique_together': "[('release', 'incoming_test', 'mapped_test')]", 'object_name': 'TestMapping'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'incoming_test': ('django.db.models.fields.CharField', [], {'max_length': '128'}),
            'mapped_test': ('django.db.models.fields.CharField', [], {'max_length': '128'}),
            'release': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['releases.Distro']"})
        }
    }

    complete_apps = ['results']
