from django.db import models, IntegrityError
from releases.models import Distro


class ImportLock(models.Model):
    locked_by = models.CharField(max_length=64)
    created_at = models.DateTimeField(auto_now_add=True)


def get_lock(locker):
    try:
        lock, created = ImportLock.objects.get_or_create(pk=1,
                            locked_by=locker)
        if created:
            return lock
        return False
    except IntegrityError:
        return False


class ImportSchedule(models.Model):
    release = models.ForeignKey(Distro, unique=True)
    import_since = models.DateTimeField(auto_now_add=True)
    full_refresh = models.BooleanField(default=False)

    def __unicode__(self):
        return u'%s' % self.release


class CategoryMapping(models.Model):
    release = models.ForeignKey(Distro)
    incoming_category = models.CharField(max_length=64)
    uf_category = models.CharField(max_length=64)

    class Meta:
        unique_together = [('release', 'incoming_category',
                            'uf_category')]

    def __unicode__(self):
        return u'%s to %s' % (self.incoming_category, self.uf_category)


class SkippableTest(models.Model):
    release = models.ForeignKey(Distro)
    # use the friendly category the test is mapped to
    uf_category = models.CharField(max_length=64)
    test = models.CharField(max_length=64)

    class Meta:
        unique_together = [('release', 'uf_category',
                            'test')]

    def __unicode__(self):
        return u'%s/%s' % (self.uf_category, self.test)


class TestMapping(models.Model):
    release = models.ForeignKey(Distro)
    incoming_test = models.CharField(max_length=128)
    mapped_test = models.CharField(max_length=128)

    class Meta:
        unique_together = [('release', 'incoming_test',
                            'mapped_test')]

    def __unicode__(self):
        return u'%s to %s' % (self.incoming_test, self.incoming_test)


def get_category_mappings(release):
    mappings = {}
    for m in CategoryMapping.objects.filter(release=release):
        mappings[m.incoming_category] = m.uf_category
    return mappings


def get_skippable_tests(release):
    tests = []
    for st in SkippableTest.objects.filter(release=release):
        tests.append('%s/%s' % (st.uf_category, st.test))
    return tests


def get_test_mappings(release):
    mappings = {}
    for m in TestMapping.objects.filter(release=release):
        mappings[m.incoming_test] = m.mapped_test
    return mappings
