# Create your views here.
from django.contrib.auth.decorators import permission_required
from django.views.decorators.http import condition
from django.shortcuts import render_to_response
from django.template import RequestContext
from django.http import HttpResponse, HttpResponseNotFound
from results.models import ImportLock
from system_configs.models import SystemUnit, RejectedSubmission, SkippedTest
import datetime
import json

REPORTS = [
    {
        'name': 'units_submitted',
        'title': 'Units submitted',
        'query': SystemUnit.objects.submitted_by_period
    },
    {
        'name': 'submissions_rejected',
        'title': 'Submissions rejected',
        'query': RejectedSubmission.objects.submitted_by_period
    },
    {
        'name': 'tests_skipped',
        'title': 'Tests skipped',
        'query': SkippedTest.objects.submitted_by_period
    },
]


@condition(etag_func=None)
@permission_required('results.change_importlock')
def index(request):
    locks = ImportLock.objects.all()
    context = RequestContext(request, {'locks': locks})
    return render_to_response('util/index.html', context)


@condition(etag_func=None)
@permission_required('results.change_importlock')
def clear_locks(request):
    ImportLock.objects.all().delete()
    return HttpResponse('1')


def _get_dates(request):
    start = request.GET.get('from', None)
    if start:
        start = _parse_date(start)
    end = request.GET.get('to', None)
    if end:
        end = _parse_date(end)
    days = int(request.GET.get('days', 14))
    return _validate_dates(start, end, days)


def _parse_date(date, delimiter='-'):
    (year, month, day) = date.split(delimiter)
    return datetime.date(int(year), int(month), int(day))


def _validate_dates(start, end, days):
    # Start, but no end
    if start and not end:
        print 'start'
        end = start + datetime.timedelta(days - 1)

    # End, but no start
    if end and not start:
        start = end - datetime.timedelta(days - 1)

    # Default to month-to-date (unless it's the 1st, then we'll use days again)
    if not (start and end):
        end = datetime.date.today()
        if end.day == 1:
            start = end - datetime.timedelta(days - 1)
        else:
            start = end - datetime.timedelta(end.day - 1)

    # Wrong way round
    if end < start:
        _start = start
        start = end
        end = _start

    if start and end:
        delta = end - start
        days = delta.days + 1

    return (start, end, days)


def data(request):
    report_name = request.GET.get('report_name')
    if report_name not in [r['name'] for r in REPORTS]:
        return HttpResponseNotFound()
    else:
        report = [r for r in REPORTS if r['name'] == report_name][0]

    (start, end, days) = _get_dates(request)

    results = report['query']('day', start - datetime.timedelta(1),
            end + datetime.timedelta(1))

    # Generate data
    data = []
    for i in range(0, days):
        period = start + datetime.timedelta(i)
        try:
            result = [r for r in results if r['period'].date() == period][0]
            period = result['period'].date()
            count = result['count']
        except IndexError:
            count = 0
        entry = {'date': period.isoformat(), 'count': count}
        data.append(entry)
    total = sum([r['count'] for r in data])
    return HttpResponse("""
{"total" : """ + str(total) + """,
"data":
    """ + json.dumps(data) + """
}

""")
